### Uploading packages-----
library(EnvStats)
require(ggplot2)
require(car)
require(ggeffects)
require(emmeans)
require(nortest)
require(corrplot)
require(gridExtra)
require(Rmisc)
require(cowplot)
require(Hmisc)
require(GGally)
require(piecewiseSEM)
require(survminer)
require(survival)
require(dplyr)
require(tidyverse)
require(broom)
require(coxme)

## Creating a work space----
setwd("/Users/zegni/Google Drive/1.Files_manuscripts/Triki et al_learning and brain/Manuscript/ProcB/Revision1/Figshare")

### Uploading datasets-----
performance_brains <- read.csv("performance_brains.csv",header=TRUE, sep=",")

performance_brains <- subset(performance_brains, tel!="NA")## removing the one fish without brain measures.
head(performance_brains)

## Adding new columns to performance_brains-----

performance_brains$Sbrain <- scale(log(performance_brains$brain_tot))
performance_brains$Sbody <- scale(log(performance_brains$body_SL))
performance_brains$Stel <- scale(log(performance_brains$tel))
performance_brains$Sot <- scale(log(performance_brains$ot))
performance_brains$Scer <- scale(log(performance_brains$cer))
performance_brains$Shyp <- scale(log(performance_brains$hyp))
performance_brains$Sdm <- scale(log(performance_brains$dm))

performance_brains$Sbrain_tel <- scale(log(performance_brains$brain_tot-performance_brains$tel))
performance_brains$Sbrain_ot <- scale(log(performance_brains$brain_tot-performance_brains$ot))
performance_brains$Sbrain_hyp <- scale(log(performance_brains$brain_tot-performance_brains$hyp))
performance_brains$Sbrain_cer <- scale(log(performance_brains$brain_tot-performance_brains$cer))
performance_brains$Sbrain_dm <- scale(log(performance_brains$brain_tot-performance_brains$dm))

########################## ASSOCIATIVE LEARNING--------------
## Total Brain size and associative learning-----

summary(b1 <- coxph(Surv(associative_score, associative_outcome) ~ 
                      Sbrain+Sbody+line+
                      cluster(colour:replicate)
                    , data = performance_brains,method="breslow")) 


## summary of the model
summary(b1)
Anova(b1)

concordance(b1)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(b1, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(b1)

test.ph <- cox.zph(b1)
test.ph

ggcoxzph(test.ph)


## model plot
plot(ggpredict(b1, terms=c("Sbrain[meansd]"), type="cumhaz"))## for definition and interpretation of risk ratio and hazard ratio see this blog: https://s4be.cochrane.org/blog/2016/04/05/tutorial-hazard-ratios/
plot(ggemmeans(b1, terms=c("Sbrain")))


## Brain regions-associative learning-------

# Telencephalon-----
summary(f1 <- coxph(Surv(associative_score, associative_outcome) ~ 
                      Stel+Sbrain_tel+line+
                      cluster(colour:replicate)
                    , data = performance_brains, method="breslow"))

## summary of the model
summary(f1)
Anova(f1)

concordance(f1)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
                ## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(f1, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(f1)

test.ph <- cox.zph(f1)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(f1, terms=c("Stel[meansd]"), type = "cumhaz"))
plot(ggpredict(f1, terms=c("Stel")))



# Optic Tectum------
summary(f2 <- coxph(Surv(associative_score, associative_outcome) ~ 
                      Sot+Sbrain_ot+line+
                      cluster(colour:replicate)
                    , data = performance_brains, method="breslow"))



## summary of the model
summary(f2)
Anova(f2)

concordance(f2)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(f2, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(f2)

test.ph <- cox.zph(f2)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(f2, terms=c("Sot[meansd]"), type = "cumhaz"))
plot(ggpredict(f2, terms=c("Sot")))

# Hypothalamus-----
summary(f3 <- coxph(Surv(associative_score, associative_outcome) ~ 
                      Shyp+Sbrain_hyp+line+
                      cluster(colour:replicate)
                    , data = performance_brains, method="breslow"))



## summary of the model
summary(f3)
Anova(f3)

concordance(f3)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(f3, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(f3)

test.ph <- cox.zph(f3)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(f3, terms=c("Shyp[meansd]"), type = "cumhaz"))
plot(ggpredict(f3, terms=c("Shyp")))

# Cerbellum-----
summary(f4 <- coxph(Surv(associative_score, associative_outcome) ~ 
                      Scer+Sbrain_cer+line+
                      cluster(colour:replicate)
                    , data = performance_brains, method="breslow"))



## summary of the model
summary(f4)
Anova(f4)

concordance(f4)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(f4, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(f4)

test.ph <- cox.zph(f4)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(f4, terms=c("Scer[meansd]"), type = "cumhaz"))
plot(ggpredict(f4, terms=c("Scer")))

# Dorsal Medulla-----
summary(f5 <- coxph(Surv(associative_score, associative_outcome) ~ 
                      Sdm+Sbrain_dm+line+
                      cluster(colour:replicate)
                    , data = performance_brains, method="breslow"))



## summary of the model
summary(f5)
Anova(f5)

concordance(f5)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(f5, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(f5)

test.ph <- cox.zph(f5)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(f5, terms=c("Sdm[meansd]"), type = "cumhaz"))
plot(ggpredict(f5, terms=c("Sdm")))

######################### REVERSAL LEARNING--------------
## Total brain size and reversal learning-----
summary(b2 <- coxph(Surv(reversal_score, reversal_outcome) ~ 
                      Sbrain+Sbody+line+
                      cluster(colour:replicate)
                    , data = performance_brains, method="breslow"))## for consitency and to compare to the previous test we use here brain residuals as well

## summary of the model
summary(b2)
Anova(b2)

concordance(b2)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(b2, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(b2)

test.ph <- cox.zph(b2)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(b2, terms=c("Sbrain[meansd]"), type="cumhaz"))
plot(ggpredict(b2, terms=c("Sbrain")))


# Telencephalon-----
summary(z1 <- coxph(Surv(reversal_score, reversal_outcome) ~ 
                      Stel+Sbrain_tel+line+
                      cluster(colour:replicate)
                    , data = performance_brains, method="breslow"))



## summary of the model
summary(z1)
Anova(z1)

concordance(z1)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(z1, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(z1)

test.ph <- cox.zph(z1)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(z1, terms=c("Stel[meansd]"), type = "cumhaz"))
plot(ggpredict(z1, terms=c("Stel")))



# Optic Tectum------
summary(z2 <- coxph(Surv(reversal_score, reversal_outcome) ~ 
                      Sot+Sbrain_ot+line+
                      cluster(colour:replicate)
                    , data = performance_brains, method="breslow"))



## summary of the model
summary(z2)
Anova(z2)

concordance(z2)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(z2, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(z2)

test.ph <- cox.zph(z2)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(z2, terms=c("Sot[meansd]"), type = "cumhaz"))
plot(ggpredict(z2, terms=c("Sot")))

# Hypothalamus-----
summary(z3 <- coxph(Surv(reversal_score, reversal_outcome) ~ 
                      Shyp+Sbrain_hyp+line+
                      cluster(colour:replicate)
                    , data = performance_brains, method="breslow"))



## summary of the model
summary(z3)
Anova(z3)

concordance(z3)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(z3, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(z3)

test.ph <- cox.zph(z3)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(z3, terms=c("Shyp[meansd]"), type = "cumhaz"))
plot(ggpredict(z3, terms=c("Shyp")))

# Cerbellum-----
summary(z4 <- coxph(Surv(reversal_score, reversal_outcome) ~ 
                      Scer+Sbrain_cer+line+
                      cluster(colour:replicate)
                    , data = performance_brains, method="breslow"))



## summary of the model
summary(z4)
Anova(z4)

concordance(z4)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(z4, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(z4)

test.ph <- cox.zph(z4)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(z4, terms=c("Scer[meansd]"), type = "cumhaz"))
plot(ggpredict(z4, terms=c("Scer")))

# Dorsal Medulla-----
summary(z5 <- coxph(Surv(reversal_score, reversal_outcome) ~ 
                      Sdm+Sbrain_dm+line+
                      cluster(colour:replicate)
                    , data = performance_brains, method="breslow"))



## summary of the model
summary(z5)
Anova(z5)

concordance(z5)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(z5, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(z5)

test.ph <- cox.zph(z5)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(z5, terms=c("Sdm[meansd]"), type = "cumhaz"))
plot(ggpredict(z5, terms=c("Sdm")))

################### Reversal Learning without Outlier------------------

## Total Brain size and reversal learning: without an outlier (fish#37 (with ID=57)-----
summary(b3 <- coxph(Surv(reversal_score, reversal_outcome) ~ Sbrain+Sbody+line+
                      cluster(colour:replicate)
                    , data = performance_brains[-34,], method="breslow"))## fish in row#34 looks like an outlier, we check by running the model without it

## summary of the model
summary(b3)
Anova(b3)

concordance(b3)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(b3, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(b3)

test.ph <- cox.zph(b3)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(b3, terms=c("brain_resid[meansd]"), type="cumhaz"))
plot(ggpredict(b3, terms=c("brain_resid")))




## Brain regions Reversal learning without outlier:without an outlier (fish#37 (with ID=57)-----

# Telencephalon
summary(z1.1 <- coxph(Surv(reversal_score, reversal_outcome) ~ 
                        Stel+Sbrain_tel+line+
                      cluster(colour:replicate)
                    , data = performance_brains[-34,], method="breslow"))



## summary of the model
summary(z1.1)
Anova(z1.1)

concordance(z1.1)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(z1.1, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(z1.1)

test.ph <- cox.zph(z1.1)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(z1.1, terms=c("Stel[meansd]"), type = "cumhaz"))
plot(ggpredict(z1.1, terms=c("Stel")))



# Optic Tectum
summary(z2.1 <- coxph(Surv(reversal_score, reversal_outcome) ~ 
                        Sot+Sbrain_ot+line+
                      cluster(colour:replicate)
                    , data = performance_brains[-34,], method="breslow"))



## summary of the model
summary(z2.1)
Anova(z2.1)

concordance(z2.1)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(z2.1, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(z2.1)

test.ph <- cox.zph(z2.1)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(z2.1, terms=c("Sot[meansd]"), type = "cumhaz"))
plot(ggpredict(z2.1, terms=c("Sot")))

# Hypothalamus
summary(z3.1 <- coxph(Surv(reversal_score, reversal_outcome) ~ 
                        Shyp+Sbrain_hyp+line+
                      cluster(colour:replicate)
                    , data = performance_brains[-34,], method="breslow"))



## summary of the model
summary(z3.1)
Anova(z3.1)

concordance(z3.1)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(z3.1, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(z3.1)

test.ph <- cox.zph(z3.1)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(z3.1, terms=c("Shyp[meansd]"), type = "cumhaz"))
plot(ggpredict(z3.1, terms=c("Shyp")))

# Cerbellum
summary(z4.1 <- coxph(Surv(reversal_score, reversal_outcome) ~ 
                        Scer+Sbrain_cer+line+
                      cluster(colour:replicate)
                    , data = performance_brains[-34,], method="breslow"))



## summary of the model
summary(z4.1)
Anova(z4.1)

concordance(z4.1)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(z4.1, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(z4.1)

test.ph <- cox.zph(z4.1)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(z4.1, terms=c("Scer[meansd]"), type = "cumhaz"))
plot(ggpredict(z4.1, terms=c("Scer")))

# Dorsal Medulla
summary(z5.1 <- coxph(Surv(reversal_score, reversal_outcome) ~ 
                        Sdm+Sbrain_dm+line+
                      cluster(colour:replicate)
                    , data = performance_brains[-34,], method="breslow"))



## summary of the model
summary(z5.1)
Anova(z5.1)

concordance(z5.1)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(z5.1, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(z5.1)

test.ph <- cox.zph(z5.1)
test.ph

ggcoxzph(test.ph)

## model plot
plot(ggpredict(z5.1, terms=c("Sdm[meansd]"), type = "cumhaz"))
plot(ggpredict(z5.1, terms=c("Sdm")))



##################################### FIGURES------------
performance_brains$brain_resid <- resid(model <- lm(log(brain_tot)~log(body_SL), data=performance_brains, 
                                                    na.action = na.exclude))# we're using residuals here to simplifiy the plots

performance_brains$tel_resid <- resid(model <- lm(log(tel)~log(brain_tot), data=performance_brains,
                                                  na.action=na.exclude))

performance_brains$ot_resid <- resid(model <- lm(log(ot)~log(brain_tot), data=performance_brains,
                                                  na.action=na.exclude))

performance_brains$cer_resid <- resid(model <- lm(log(cer)~log(brain_tot), data=performance_brains,
                                                  na.action=na.exclude))

performance_brains$hyp_resid <- resid(model <- lm(log(hyp)~log(brain_tot), data=performance_brains,
                                                  na.action=na.exclude))

performance_brains$dm_resid <- resid(model <- lm(log(dm)~log(brain_tot), data=performance_brains,
                                                  na.action=na.exclude))

head(performance_brains)
data <- performance_brains[,c("associative_score", "associative_outcome", "reversal_score",
                              "brain_resid", "tel_resid", "ot_resid", "cer_resid","hyp_resid",  "dm_resid")]

head(data)

mdata <- reshape::melt(data, id=c("associative_score", "associative_outcome", "reversal_score"))
head(mdata)
mdata$variable

cbp1 <- c("#999999", "#E69F00", "#56B4E9", "#009E73",
          "#F0E442", "#0072B2", "#D55E00", "#CC79A7")



labs <- c("Brain", "Telencephalon",  "Optic tectum", 
           "Cerebellum","Hypothalamus", "Dorsal medulla")
names(labs) <- c("brain_resid", "tel_resid", "ot_resid", "cer_resid","hyp_resid",  "dm_resid")

## Figure 1-----
## associative raw data plots
plot1 <- ggplot(mdata, aes(x=value, y=associative_score, 
                               shape=as.factor(associative_outcome), 
                  colour=variable))+
  geom_point()+expand_limits(y=0)+scale_y_reverse()+
  theme_classic()+
  theme(legend.position = "none",
        axis.text.x=element_text(size=6),
        strip.text.x = element_text(size=0),
        strip.background = element_blank())+
  facet_wrap(~variable, scale="free", ncol=6,
             labeller = labeller(variable = labs))+
  scale_shape_manual(values=c(15, 19))+
  scale_colour_manual(values=cbp1)+xlab("")+
  ylab("Associative learning")

plot1

## associative-model predictions

p1 <- plot(ggpredict(b1, terms=c("Sbrain")), show.title = F)+ylim(0,3)+
  xlab("Brain")+theme_classic()+theme(axis.text.x=element_text(size=6))

p2 <- plot(ggpredict(f1, terms=c("Stel")), show.title = F, show.y.title = F)+ylim(0,3)+
  xlab("Telencephalon")+theme_classic()+theme(axis.text.x=element_text(size=6))

p3 <- plot(ggpredict(f2, terms=c("Sot")), show.title = F, show.y.title = F)+ylim(0,3)+
  xlab("Optic tectum")+theme_classic()+theme(axis.text.x=element_text(size=6))

p4 <- plot(ggpredict(f3, terms=c("Shyp")), show.title = F, show.y.title = F)+ylim(0,3)+
  xlab("Hypothalamus")+theme_classic()+theme(axis.text.x=element_text(size=6))

p5 <- plot(ggpredict(f4, terms=c("Scer")), show.title = F, show.y.title = F)+ylim(0,4)+
  xlab("Cerebellum")+theme_classic()+theme(axis.text.x=element_text(size=6))

p6 <- plot(ggpredict(f5, terms=c("Sdm")), show.title = F, show.y.title = F)+ylim(0,3)+
  xlab("Dorsal medulla")+theme_classic()+theme(axis.text.x=element_text(size=6))

prow1 <- cowplot::plot_grid(p1,p2,p3,p4,p5,p6,
                   ncol=6,label_size=11, align = c("h", "v"), 
                   labels=c(""), label_x=-0.05,
                   rel_widths = c(0.14,0.12, 0.12, 0.12, 0.12, 0.12))

prow1

Fig1 <- cowplot::plot_grid(plot1,prow1, ncol=1, rel_heights = c(1, 1))
Fig1

# Figure 2------------

## reversal raw data plots
plot2 <- ggplot(mdata, aes(x=value, y=reversal_score, 
                           colour=variable))+
  geom_point()+expand_limits(y=0)+scale_y_reverse()+
  theme_classic()+
  theme(legend.position = "none",
        axis.text.x=element_text(size=6),
        strip.text.x = element_text(size=0),
        strip.background = element_blank(),
        panel.spacing = unit(1.2, "lines"))+
  facet_wrap(~variable, scale="free", ncol=6,
             labeller = labeller(variable = labs))+
  scale_shape_manual(values=c(15, 19))+
  scale_colour_manual(values=cbp1)+xlab("")+
  ylab("Reversal learning")

plot2


## reversal-model predictions

t1 <- plot(ggpredict(b1, terms=c("Sbrain")), show.title = F)+ylim(0,3)+
 xlab("Brain")+theme_classic()+theme(axis.text.x=element_text(size=6))

t2 <- plot(ggpredict(z1, terms=c("Stel")), show.title = F, show.y.title = F)+ylim(0,3)+
 xlab("Telencephalon")+theme_classic()+theme(axis.text.x=element_text(size=6))

t3 <- plot(ggpredict(z2, terms=c("Sot")), show.title = F, show.y.title = F)+ylim(0,3)+
 xlab("Optic tectum")+theme_classic()+theme(axis.text.x=element_text(size=6))

t4 <- plot(ggpredict(z3, terms=c("Shyp")), show.title = F, show.y.title = F)+ylim(0,3)+
 xlab("Hypothalamus")+theme_classic()+theme(axis.text.x=element_text(size=6))

t5 <- plot(ggpredict(z4, terms=c("Scer")), show.title = F, show.y.title = F)+ylim(0,3)+
 xlab("Cerebellum")+theme_classic()+theme(axis.text.x=element_text(size=6))

t6 <- plot(ggpredict(z5, terms=c("Sdm")), show.title = F, show.y.title = F)+ylim(0,3)+
  xlab("Dorsal medulla")+theme_classic()+theme(axis.text.x=element_text(size=6))

prow2 <- cowplot::plot_grid(t1,t2,t3,t4,t5,t6,
                   ncol=6,label_size=11, align = c("h", "v"), 
                   labels=c(""), label_x=-0.05,
                   rel_widths = c(0.14,0.12, 0.12, 0.12, 0.12, 0.12))

prow2

Fig2 <- cowplot::plot_grid(plot2,prow2, ncol=1, rel_heights = c(1, 1))
Fig2



###################### Supplementary Material-------------


## FigS1----

FigS1 <- gghistogram(
  performance_brains, x = "tel_resid", 
  add = "mean", rug = TRUE,
  fill = "line", palette = c("#00AFBB", "#E7B800", "red"),
  add_density = F)## for telencephalon size residuals

FigS1# panel (b) for this figure is the marginal plot form the main model with the function "ggeffect" (see above)


## Telencephalon size model-------

performance_brains$brain_rest <- performance_brains$brain_tot-performance_brains$tel

Anova(model <- lm(log(tel)~line*log(brain_tot)+replicate,
                  na.action=na.exclude,
                  data=performance_brains))## with lmer function replicate has zero variance (singular fit)

summary (model)

## model diagnostic
plot(resid(model))
qqPlot(resid(model))
lillie.test(resid(model))

## 95% confidence interval
confint(model, level=0.95)

## Explained varaince 
rsquared(model)

## model plot
plot(ggeffect(model, terms=c("brain_tot","line")))+
  xlab("log(brain)")+ylab("log telencephalon")## this is panel (b) for FigS1 (see below)

#### Selection lines-associative learning-----
summary(b0.0 <- coxph(Surv(associative_score, associative_outcome) ~ line+
                        cluster(colour:replicate)
                      , data = performance_brains, method="breslow"))


## summary of the model
summary(b0.0)
Anova(b0.0)

concordance(b0.0)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(b0.0, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(b0.0)

test.ph <- cox.zph(b0.0)
test.ph

ggcoxzph(test.ph)

## Fig. S2a
fit<- survfit(Surv(associative_score, associative_outcome) ~ line
                   , data = performance_brains)

# Basic survival curves
ggsurvplot(fit, data = performance_brains,fun = "cumhaz")

#### Selection lines-reversal learning-----
summary(b0.1 <- coxph(Surv(reversal_score, reversal_outcome) ~ line+
                        cluster(colour:replicate)
                      , data = performance_brains, method="breslow"))


## summary of the model
summary(b0.1)
Anova(b0.1)

concordance(b0.1)## Concordance index= goodness of fit for coxph models, also visible in the summary call. check https://cran.r-project.org/web/packages/survival/vignettes/concordance.pdf
## C > 0.5 implies a good prediction ability


## Cox model assumptions
ggcoxdiagnostics(b0.1, type = "deviance",
                 linear.predictions = F, ggtheme = theme_bw())

ggcoxfunctional(b0.1)

test.ph <- cox.zph(b0.1)
test.ph

ggcoxzph(test.ph)


## Fig. S2b
fit<- survfit(Surv(reversal_score, reversal_outcome) ~ line
              , data = performance_brains)

# Basic survival curves
ggsurvplot(fit, data = performance_brains,fun = "cumhaz")


# FigS3-----
plot3 <- ggplot(subset(mdata, reversal_score!="60"), aes(x=value, y=reversal_score, 
                                                         colour=variable))+
  geom_point()+expand_limits(y=0)+scale_y_reverse()+
  theme_classic()+
  theme(legend.position = "none",
        axis.text.x=element_text(size=7),
        strip.text.x = element_text(size=0),
        strip.background = element_blank(),
        panel.spacing = unit(1.2, "lines"))+
  facet_wrap(~variable, scale="free", ncol=6,
             labeller = labeller(variable = labs))+
  scale_shape_manual(values=c(15, 19))+
  scale_colour_manual(values=cbp1)+xlab("")+
  ylab("Reversal learning")


plot3
## reversal-model predictions
s1 <- plot(ggpredict(b3, terms=c("Sbrain")), show.title = F)+ylim(0,3)+
  xlab("Brain")+theme_classic()

s2 <- plot(ggpredict(z1.1, terms=c("Stel")), show.title = F, show.y.title = F)+ylim(0,3)+
  xlab("Telencephalon")+theme_classic()

s3 <- plot(ggpredict(z2.1, terms=c("Sot")), show.title = F, show.y.title = F)+ylim(0,3)+
  xlab("Optic tectum")+theme_classic()

s4 <- plot(ggpredict(z3.1, terms=c("Shyp")), show.title = F, show.y.title = F)+ylim(0,3)+
  xlab("Hypothalamus")+theme_classic()

s5 <- plot(ggpredict(z4.1, terms=c("Scer")), show.title = F, show.y.title = F)+ylim(0,3)+
  xlab("Cerebellum")+theme_classic()

s6 <- plot(ggpredict(z5.1, terms=c("Sdm")), show.title = F, show.y.title = F)+ylim(0,3)+
  xlab("Dorsal medulla")+theme_classic()

prowS3 <- cowplot::plot_grid(s1,s2,s3,s4,s5,s6,
                   ncol=6,label_size=11, align = c("h", "v"), 
                   labels=c(""), label_x=-0.05,
                   rel_widths = c(0.14,0.12, 0.12, 0.12, 0.12, 0.12))


prowS3

FigS3 <- cowplot::plot_grid(plot3,prowS3, ncol=1, rel_heights = c(1, 1))
FigS3



### FigS4 Correlation matrix------

head(performance_brains)
ggpairs(log(performance_brains[,c(10:14,16)]),
        lower = list(combo="facethist", 
                     continuous = wrap("smooth", alpha = 0.3)),
        upper = list(continuous = wrap("cor", method = "spearman")))

cor.test(performance_brains$ot_resid, performance_brains$tel_resid, 
         method = "spearman")




